@@ -2,9 +2,9 @@ import typing
 import types
 import abc
 import inspect
-from typing import Mapping, Sequence, TypeAlias, TypeVar
+from typing import Any, Mapping, Sequence, TypeAlias, TypeVar, Optional
 
-_JSON_DATA: TypeAlias = str | int | None | Sequence["_JSON_DATA"] | Mapping[str, "_JSON_DATA"]
+_JSON_DATA: TypeAlias = str | int | None | Sequence[object] | Mapping[str, object]
 T = TypeVar("T")
 
 
@@ -48,7 +48,7 @@ def _get_fields(cls: type) -> list[tuple[str, str, type]]:
     return fields
 
 
-def _deserialize_union(name: str, value: object, expected_type: object, module_scope: dict[str, object]) -> object:
+def _deserialize_union(name: str, value: object, expected_type: object, module_scope: dict[str, object]) -> Any:
     accepted_types: tuple[type, ...] = typing.get_args(expected_type)
 
     errors: list[str] = []
@@ -63,7 +63,16 @@ def _deserialize_union(name: str, value: object, expected_type: object, module_s
 
     return value  # type: ignore
 
-def deserialize_value(name: str, value: _JSON_DATA, expected_type: object, module_scope: dict[str, object]) -> object:
+def deserialize_value(name: str, value: _JSON_DATA, expected_type: object, module_scope: dict[str, object]) -> Any:
+    """
+    Deserialize any specific value, can be any supported hint including union!
+
+    `name` will be included in any error messages produced!
+
+    `module_scope` will be used to resolve forward referenced type hints, for example `dict[str, "ModelA"]`. this can usually just be `globals()`
+
+    >>> deserialize_value("...", ..., ModelA | ModelB, globals())
+    """
     if isinstance(expected_type, str):
         expected_type = eval(expected_type, globals(), module_scope)
 
@@ -95,6 +104,9 @@ def deserialize_value(name: str, value: _JSON_DATA, expected_type: object, modul
         return _deserialize_union(name, value, expected_type, module_scope)
 
     if issubclass(expected_type, JsonModel):
+        if isinstance(value, expected_type):
+            return value
+            
         return expected_type(value)
 
     if issubclass(expected_type, JsonConverterModel):
@@ -146,6 +158,12 @@ class JsonModel:
     >>> SimpleExample({"stuff": "wrong"})
     TypeError: ...
 
+    You can also use keyword arguments to specify values in a nicer format.
+    >>> class SimpleExample(JsonModel):
+    ...     stuff: int
+    >>> SimpleExample(stuff = 10).stuff
+    10
+
     It also supports unions (both `typing.Union` and 3.10 `|` syntax).
     >>> class UnionExample(JsonModel):
     ...     stuff: int | str
@@ -168,17 +186,15 @@ class JsonModel:
     10
     """
 
-    def __init__(self, data: _JSON_DATA):
+    def __init__(self, data: Optional[_JSON_DATA] = None, **kwargs: object):
+        if data is None:
+            data = kwargs
+
         if not isinstance(data, dict):
             raise TypeError("Expected dict")
-        
+
         # error check data
         fields = _get_fields(self.__class__)
-
-        unused_keys = data.keys() - {json_key for _, json_key, _ in fields}
-        if len(unused_keys) != 0:
-            raise ValueError(f"Unexpected keys: {unused_keys}")
-
         module = inspect.getmodule(self.__class__)
 
         for name, json_key, expected_type in fields:
