@@ -12,9 +12,9 @@ def test_deserialize() -> None:
 def test_serialize() -> None:
     assert EmptyModel({}).to_json() == {}
 
-def test_extra_keys() -> None:
-    with pytest.raises(ValueError):
-        EmptyModel({"extra": 123})
+# def test_extra_keys() -> None:
+#     with pytest.raises(ValueError):
+#         EmptyModel({"extra": 123})
  
 def test_wrong_type() -> None:
     with pytest.raises(TypeError):
